@@ -57,8 +57,8 @@
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <locale.h>
 #ifdef HAS_OPENBABEL_2
-#	include <mol.h>
-#	include <obconversion.h>
+#	include <openbabel/mol.h>
+#	include <openbabel/obconversion.h>
 #else
 #	include <sstream>
 #endif
@@ -119,10 +119,6 @@ bool	gcpApplication::m_bInit = false;
 bool	gcpApplication::m_Have_Ghemical = false;
 map<string, string> gcpApplication::m_SupportedPixbufFormats;
 
-#warning "the following lines should be removed for stable releases"
-#undef PACKAGE
-#define PACKAGE "gchempaint-unstable" 
-
 gcpApplication::gcpApplication ()
 {
 	Apps.push_back(this);
@@ -430,6 +426,8 @@ bool gcpApplication::FileProcess(const gchar* filename, int filetype, bool bSave
 		}
 		if (result == GTK_RESPONSE_YES)
 		{
+			// destroy the old file
+			gnome_vfs_unlink (filename2);
 #ifdef HAS_OPENBABEL_2
 			pDoc->SetType (filetype);
 			if (filetype == gcp_ft_Normal)
