@@ -24,14 +24,16 @@
  * USA
  */
 
-#include <mol.h>
-#undef PACKAGE
-#undef PACKAGE_BUGREPORT
-#undef PACKAGE_NAME
-#undef PACKAGE_STRING
-#undef PACKAGE_TARNAME
-#undef PACKAGE_VERSION
-#undef VERSION
+#ifndef HAS_OPENBABEL_2
+#	include <mol.h>
+#	undef PACKAGE
+#	undef PACKAGE_BUGREPORT
+#	undef PACKAGE_NAME
+#	undef PACKAGE_STRING
+#	undef PACKAGE_TARNAME
+#	undef PACKAGE_VERSION
+#	undef VERSION
+#endif
 
 #include "gchempaint-config.h"
 #include "atom.h"
@@ -48,6 +50,9 @@
 #include "libgcpcanvas/gcp-canvas-text.h"
 #include <math.h>
 #include <gcu/element.h>
+#ifdef HAS_OPENBABEL_2
+#	include <openbabel/mol.h>
+#endif
 
 using namespace gcu;
 
