@@ -4,7 +4,7 @@
  * GChemPaint library
  * mesomery-arrow.cc 
  *
- * Copyright (C) 2004
+ * Copyright (C) 2004-2005
  *
  * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
@@ -20,7 +20,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -43,6 +43,12 @@ gcpMesomeryArrow::gcpMesomeryArrow (gcpMesomery* mesomery): gcpArrow (MesomeryAr
 
 gcpMesomeryArrow::~gcpMesomeryArrow ()
 {
+	if (IsLocked ())
+		return;
+	if (m_Start && m_End) {
+		m_Start->RemoveArrow (this, m_End);
+		m_End->RemoveArrow (this, m_Start);
+	}
 }
 
 xmlNodePtr gcpMesomeryArrow::Save (xmlDocPtr xml)
@@ -78,7 +84,32 @@ xmlNodePtr gcpMesomeryArrow::Save (xmlDocPtr xml)
 
 bool gcpMesomeryArrow::Load (xmlNodePtr node)
 {
-	return gcpArrow::Load (node);
+	char *buf;
+	Object *parent;
+	if (gcpArrow::Load (node)) {
+		parent = GetParent ();
+		if (!parent)
+			return true;
+		buf = (char*) xmlGetProp (node, (xmlChar*) "start");
+		if (buf) {
+			m_Start = reinterpret_cast<gcpMesomer*> (parent->GetDescendant (buf));
+			xmlFree (buf);
+			if (!m_Start)
+				return false;
+		}
+		buf = (char*) xmlGetProp (node, (xmlChar*) "end");
+		if (buf) {
+			m_End = reinterpret_cast<gcpMesomer*> (parent->GetDescendant (buf));
+			xmlFree (buf);
+			if (!m_End)
+				return false;
+			m_End->AddArrow (this, m_Start);
+		}
+		if (m_Start)
+			m_Start->AddArrow (this, m_End);
+		return true;
+	}
+	return false;
 }
 
 void gcpMesomeryArrow::Add (GtkWidget* w)
@@ -126,3 +157,14 @@ void gcpMesomeryArrow::Update (GtkWidget* w)
 						NULL);
 	gnome_canvas_points_free (points);
 }
+
+void gcpMesomeryArrow::Reverse ()
+{
+	gcpMesomer *mesomer = m_Start;
+	m_Start= m_End;
+	m_End = mesomer;
+	m_x = m_x + m_width;
+	m_y = m_y + m_height;
+	m_width = - m_width;
+	m_height = - m_height;
+}
