@@ -20,7 +20,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -91,6 +91,7 @@ bool gcpTextTool::OnClicked()
 		g_object_set(G_OBJECT(m_Active), "editable", true, "cursor_visible", true, NULL);
 		m_CurNode = ((gcpText*)m_pObject)->SaveSelected();
 		m_InitNode = ((gcpText*)m_pObject)->SaveSelected();
+		m_pApp->ActivateMenu ("Image", false);
 	}
 	return true;
 }
@@ -134,24 +135,24 @@ bool gcpTextTool::OnEvent(GdkEvent* event)
 						CutSelection(gtk_clipboard_get(GDK_SELECTION_CLIPBOARD));
 						return true;
 					case GDK_i:
-						gtk_toggle_tool_button_set_active((GtkToggleToolButton*)m_pApp->GetToolItem("Italic"),
-											!gtk_toggle_tool_button_get_active((GtkToggleToolButton*)m_pApp->GetToolItem("Italic")));
+						gtk_toggle_tool_button_set_active((GtkToggleToolButton*)m_pApp->GetToolItem("italic"),
+											!gtk_toggle_tool_button_get_active((GtkToggleToolButton*)m_pApp->GetToolItem("italic")));
 						return true;
 					case GDK_u:
-						gtk_toggle_tool_button_set_active((GtkToggleToolButton*)m_pApp->GetToolItem("Underline"),
-											!gtk_toggle_tool_button_get_active((GtkToggleToolButton*)m_pApp->GetToolItem("Underline")));
+						gtk_toggle_tool_button_set_active((GtkToggleToolButton*)m_pApp->GetToolItem("underline"),
+											!gtk_toggle_tool_button_get_active((GtkToggleToolButton*)m_pApp->GetToolItem("underline")));
 						return true;
 					case GDK_b:
-						gtk_toggle_tool_button_set_active((GtkToggleToolButton*)m_pApp->GetToolItem("Bold"),
-											!gtk_toggle_tool_button_get_active((GtkToggleToolButton*)m_pApp->GetToolItem("Bold")));
+						gtk_toggle_tool_button_set_active((GtkToggleToolButton*)m_pApp->GetToolItem("bold"),
+											!gtk_toggle_tool_button_get_active((GtkToggleToolButton*)m_pApp->GetToolItem("bold")));
 						return true;
 					case GDK_plus:
-						gtk_toggle_tool_button_set_active((GtkToggleToolButton*)m_pApp->GetToolItem("Superscript"),
-											!gtk_toggle_tool_button_get_active((GtkToggleToolButton*)m_pApp->GetToolItem("Superscript")));
+						gtk_toggle_tool_button_set_active((GtkToggleToolButton*)m_pApp->GetToolItem("superscript"),
+											!gtk_toggle_tool_button_get_active((GtkToggleToolButton*)m_pApp->GetToolItem("superscript")));
 						return true;
 					case GDK_equal:
-						gtk_toggle_tool_button_set_active((GtkToggleToolButton*)m_pApp->GetToolItem("Subscript"),
-											!gtk_toggle_tool_button_get_active((GtkToggleToolButton*)m_pApp->GetToolItem("Subscript")));
+						gtk_toggle_tool_button_set_active((GtkToggleToolButton*)m_pApp->GetToolItem("subscript"),
+											!gtk_toggle_tool_button_get_active((GtkToggleToolButton*)m_pApp->GetToolItem("subscript")));
 						return true;
 					default:
 						return true;
@@ -296,6 +297,7 @@ bool gcpTextTool::Unselect()
 		m_pView->GetDoc()->Remove(pObj);
 		m_pView->GetDoc()->AbortOperation();
 	}
+	m_pApp->ActivateMenu ("Image", m_pView->GetDoc()->HasChildren ());
 	return true;
 }
 
@@ -401,25 +403,33 @@ bool gcpTextTool::DeleteSelection()
 	return true;
 }
 
-bool gcpTextTool::CopySelection(GtkClipboard *clipboard)
+bool gcpTextTool::CopySelection (GtkClipboard *clipboard)
 {
-	if (!m_Active) return false;
-	GtkTextBuffer* buf = gnome_canvas_rich_text_ext_get_buffer(m_Active);
+	if (!m_Active)
+		return false;
+	GtkTextBuffer* buf = gnome_canvas_rich_text_ext_get_buffer (m_Active);
 	GtkTextIter start, end;
-	gtk_text_buffer_get_selection_bounds(buf, &start, &end);
-	if (gtk_text_iter_equal(&start, &end)) return false; //Nothing to copy
-	m_pData->Copy(clipboard); //To clean the xmlDoc
-	xmlDocPtr pDoc = m_pData->GetXmlDoc(clipboard);
-	if (!pDoc) return false;
-	pDoc->children = xmlNewDocNode(pDoc, NULL, (xmlChar*)"chemistry", NULL);
-	gcpText *text = (gcpText*)g_object_get_data(G_OBJECT(m_Active), "object");
-	xmlNodePtr node = text->SaveSelection(pDoc);
-	if (node) xmlAddChild(pDoc->children, node);
-	else return false;
-	gtk_clipboard_set_with_data(clipboard, targets, 2,
-		(GtkClipboardGetFunc)on_get_data,
-		(GtkClipboardClearFunc)on_clear_data, NULL);
-	gtk_clipboard_request_contents(clipboard, gdk_atom_intern ("TARGETS", FALSE),  (GtkClipboardReceivedFunc)on_receive_targets, NULL);
+	gtk_text_buffer_get_selection_bounds (buf, &start, &end);
+	if (gtk_text_iter_equal (&start, &end))
+		return false; //Nothing to copy
+	m_pData->Copy (clipboard); //To clean the xmlDoc
+	xmlDocPtr pDoc = m_pData->GetXmlDoc (clipboard);
+	if (!pDoc)
+		return false;
+	pDoc->children = xmlNewDocNode (pDoc, NULL, (xmlChar*) "chemistry", NULL);
+	gcpText *text = (gcpText*) g_object_get_data (G_OBJECT (m_Active), "object");
+	xmlNodePtr node = text->SaveSelection (pDoc);
+	if (node)
+		xmlAddChild (pDoc->children, node);
+	else
+		return false;
+	gtk_clipboard_set_with_data (clipboard, targets, 2,
+		(GtkClipboardGetFunc) on_get_data,
+		(GtkClipboardClearFunc) on_clear_data, this);
+	gtk_clipboard_request_contents (clipboard,
+			gdk_atom_intern ("TARGETS", FALSE),
+			(GtkClipboardReceivedFunc) on_receive_targets,
+			m_pApp);
 	return true;
 }
 
@@ -615,5 +625,5 @@ void gcpTextTool::OnGetData(GtkClipboard *clipboard, GtkSelectionData *selection
 		gtk_selection_data_set(selection_data, gdk_atom_intern (GCHEMPAINT_ATOM_NAME, FALSE), 8,  (const guchar*) ClipboardData, size);
 	}
 	cleared = false;
-	if (clipboard == gtk_clipboard_get(GDK_SELECTION_CLIPBOARD)) m_pApp->ActivateMenu("Paste", true);
+	if (clipboard == gtk_clipboard_get (GDK_SELECTION_CLIPBOARD)) m_pApp->ActivateMenu("Paste", true);
 }
