@@ -513,7 +513,7 @@ BonoboObject * gchempaint_factory(BonoboGenericFactory * fact, const char *compo
 	gcpBonoboApp* App = new gcpBonoboApp();
 	gcpDocument* pDoc =  new gcpDocument(App, false);
 	if (!pDoc) return NULL;
-	if (!strcmp (component_id, "OAFIID:gchempaint_unstable_control"))
+	if (!strcmp (component_id, "OAFIID:gchempaint_control"))
 	{
 		retval = (BonoboObject*) gcp_bonobo_control_new(pDoc);
 		if (!retval)  delete pDoc;
@@ -536,6 +536,6 @@ int main (int argc, char *argv[])
 #endif
 	textdomain(PACKAGE);
 	gtk_init (&argc, &argv);
-	BONOBO_FACTORY_INIT ("gchempaint_unstable", VERSION, &argc, argv);		
-	return bonobo_generic_factory_main ("OAFIID:gchempaint_unstable_factory", gchempaint_factory, NULL);
+	BONOBO_FACTORY_INIT ("gchempaint", VERSION, &argc, argv);		
+	return bonobo_generic_factory_main ("OAFIID:gchempaint_factory", gchempaint_factory, NULL);
 }
